Modules
Structs
A wrapper around raw 12-byte ObjectId representations.
Enums
Traits
An asynchronous trait designed to simplify the creation of Axum APIs
Scaffold the framework for the swift implementation of a CLI application built on top of clap
Functions
Type Definitions
Outlines the expected type for a block hash
Describes the type expected when considering a block id from a blockchain
Describes the type expected when considering a block nonce from a block on-chain.
Defines a block of transactions to be an array of 16 transactions
Describes the type expected when considering a block timestamp from a block on-chain.
Defines the timezone implemented for each temporal ledger on-chain.
Defines a dynamic standard error with send, sync, and static features
Describes the result of a collection of configuration files
Describes a configuration builder in their default state
A simplistic wrapper for the HashMap
Assigns a